@@ -3,6 +3,9 @@ from psycopg2 import sql
 
 def getAbi(connection, schema, token_address, chain_id):
     
+    #NOTE: ABI not in DB for now (Sept. 2022)
+    return None
+
     query = sql.SQL("SELECT abi FROM {}.evm_token \
            WHERE chain_id = %s AND token_address = %s").format(sql.Identifier(schema))
            
@@ -16,6 +19,9 @@ def getAbi(connection, schema, token_address, chain_id):
 
 def updateAbi(connection, schema, abi, token_address, chain_id):
     
+    #NOTE: ABI not in DB for now (Sept. 2022)
+    return None
+    
     query = sql.SQL("UPDATE {}.evm_token \
            SET abi=%s \
            WHERE chain_id = %s AND token_address = %s").format(sql.Identifier(schema))
