@@ -170,16 +170,53 @@ def SELECT(connection, schema, columns:list, tableName:str, conditions:dict={}):
     
     sqlTemplateEqual = "{} = %s"
     sqlTemplateIn = "{} IN ({})"
+    sqlTemplateNotIn = "{} NOT IN ({})"
+    sqlTemplateIsNull = "{} IS NULL"
+    sqlTemplateIsNotNull = "{} IS NOT NULL"
+
+    sqlTemplateLt = "{} < %s"
+    sqlTemplateLte = "{} <= %s"
+    sqlTemplateGt = "{} > %s"
+    sqlTemplateGte = "{} >= %s"
     conditionArray = []
     params = []
     for key in conditions.keys():
-        if type(conditions[key]) == list:
-            conditionArray.append(sqlTemplateIn.format(key,','.join(['%s'] * len(conditions[key]))))
-            for item in conditions[key]:
+        if type(conditions[key]) == dict:
+            conditionValue = conditions[key]['value']
+            sqlTemplate = None
+            if conditions[key]['operator'] == 'lt':
+                sqlTemplate = sqlTemplateLt
+            elif conditions[key]['operator'] == 'lte':
+                sqlTemplate = sqlTemplateLte
+            elif conditions[key]['operator'] == 'gt':
+                sqlTemplate = sqlTemplateGt
+            elif conditions[key]['operator'] == 'gte':
+                sqlTemplate = sqlTemplateGte
+            elif conditions[key]['operator'] == 'not in':
+                sqlTemplate = sqlTemplateNotIn
+            elif conditions[key]['operator'] == 'in':
+                sqlTemplate = sqlTemplateIn
+            elif conditions[key]['operator'] == 'is not':
+                sqlTemplate = sqlTemplateIsNotNull
+        else:
+            conditionValue = conditions[key]
+            if conditionValue is None:
+                sqlTemplate = sqlTemplateIsNull
+            else:
+                sqlTemplate = sqlTemplateEqual
+        
+        
+        if type(conditionValue) == list:
+            if sqlTemplate is None or sqlTemplate not in (sqlTemplateIn,sqlTemplateNotIn):
+                conditionArray.append(sqlTemplateIn.format(key,','.join(['%s'] * len(conditionValue))))
+            else:
+                conditionArray.append(sqlTemplate.format(key,','.join(['%s'] * len(conditionValue))))
+            for item in conditionValue:
                 params.append(item) 
         else:
-            conditionArray.append(sqlTemplateEqual.format(key))
-            params.append(conditions[key]) 
+            conditionArray.append(sqlTemplate.format(key))
+            if conditionValue is not None:
+                params.append(conditionValue) 
    
     if len(conditionArray) == 0:
         queryString = "SELECT {} FROM {{}}.{}".format(', '.join(columns),tableName)
@@ -272,6 +309,20 @@ def SELECT_FUNCTION(connection, schema,functionName,functionParameter:list,colum
 #         os.environ.get("HEROKU_PORT"),
 #         os.environ.get("HEROKU_DB")
 #     )
+#     conditions = {
+#         'transaction_type': {
+#             'operator': 'not in',
+#             'value': ["auth","blub"]
+#         },
+#         'listaccounthistory_data': None,
+#         'block_number': {
+#             'operator': 'lte',
+#             'value': 1760000
+#         }
+
+#     }
+#     conditions = {'transaction_type': "auth"}
+#     SELECT(connection,os.environ.get("ENVIRONMENT"),[],'dfi_blockchain_data',conditions)
 
 #     r = POST_BULK(connection,'dbdev','testbulk',[{'number':2}],True)
 #     print(r)
